SqlManager class

数据库管理

Constructors

SqlManager()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

dbName ↔ String
getter/setter pair
dbVersion ↔ int
getter/setter pair

Static Methods

close() → dynamic
关闭
getCurrentDatabase() → Future<Database>
获取当前数据库对象
init() → dynamic
初始化
isTableExits(String tableName) → dynamic
表是否存在