BaseEntity class

Mixed-in types

Constructors

BaseEntity()

Properties

code ↔ String?
getter/setter pair
data ↔ dynamic
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
msg ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time ↔ String?
getter/setter pair

Methods

fromJson(Map<String, dynamic> json) → BaseEntity
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited