S class

Constructors

S()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strAppHttpErr → String
Request was aborted!
no setter
strNetworkError → String
Network error, please try again!
no setter
strTimeNow → String
Right now
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
strTimeDays(Object time) → String
{time} days ago
strTimeHours(Object time) → String
{time} hours ago
strTimeMin(Object time) → String
{time} min ago
strTimeSeconds(Object time) → String
{time} seconds ago
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

current → S
no setter

Static Methods

load(Locale locale) → Future<S>
maybeOf(BuildContext context) → S?
of(BuildContext context) → S

Constants

delegate → const AppLocalizationDelegate