EditTextWidget class

Inheritance

Constructors

EditTextWidget({Key? key, ITextInputType keyboardType = ITextInputType.text, int? minLines, int maxLines = 1, String? hintText, TextStyle? hintStyle, InputWidgetDelCallBack? fieldCallBack, Icon? deleteIcon, InputBorder? inputBorder, TextStyle? textStyle, Widget? prefixIcon, FormFieldValidator<String>? validator, Color? fillColor, String inputText = '', TextAlign textAlign = TextAlign.start, bool enabled = true, int? inputMaxLength, ValueChanged<String>? onSubmitted, FocusNode? focusNode, required Color cursorColor})

Properties

cursorColor → Color
final
deleteIcon → Icon?
final
enabled → bool
final
fieldCallBack → InputWidgetDelCallBack?
final
fillColor → Color?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hintStyle → TextStyle?
final
hintText → String?
final
inputBorder → InputBorder?
final
inputMaxLength → int?
final
inputText → String
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → ITextInputType
final
maxLines → int
final
minLines → int?
final
onSubmitted → InputWidgetDelCallBack?
final
prefixIcon → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAlign → TextAlign
final
textStyle → TextStyle?
final
validator → FormFieldValidator<String>?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<EditTextWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited