CardAnimation class

Constructors

CardAnimation()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

backCardAlign(AnimationController controller, Alignment beginAlign, Alignment endAlign) → Animation<Alignment>
backCardSize(AnimationController controller, Size beginSize, Size endSize) → Animation<Size?>
frontCardAlign(AnimationController controller, Alignment? beginAlign, Alignment baseAlign, double swipeEdge, bool swipeUp, bool swipeDown) → Animation<Alignment>
frontCardRota(AnimationController controller, double beginRot) → Animation<double>