AppInfoUtil class

单例的公共类-系统配置,充值,礼物

Constructors

AppInfoUtil()
factory

Properties

androidDeviceInfo ↔ AndroidDeviceInfo
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iosDeviceInfo ↔ IosDeviceInfo
getter/setter pair
packageInfo ↔ PackageInfo
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getDeviceInfo() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → AppInfoUtil?
no setter