MediaUtil class

媒体工具,负责申请权限,选照片,拍照,录音,播放语音

Constructors

MediaUtil()
factory

Properties

delegate ↔ OnMediaPluginDelegate?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkDenied(PermissionStatus status) → bool
grantedPermissions(dynamic context, {bool chat = false, int index = -1}) → Future<bool?>
initMediaUtil(OnMediaPluginDelegate delegate) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermissions(dynamic back, {bool chat = true, int index = -1}) → void
requestPermissionsNotification() → void
showDenied(bool chat, int index) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → MediaUtil?
no setter