NavigatorUtils class

导航类

Constructors

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

clicks ↔ int
getter/setter pair
downFn ↔ Function?
getter/setter pair
goGuide ↔ VoidCallback?
getter/setter pair
jumpTime ↔ int
getter/setter pair
routeMap ↔ Map
getter/setter pair

Static Methods

debounce(Function fn, [int t = 500]) → VoidCallback
防止多次点击
goGuide2() → dynamic
公共打开方式
pageContainer(dynamic context, dynamic widget) → Widget
Page页面的容器,做一次通用自定义
popUntil(BuildContext context, String name) → dynamic
showBaseDialog<T>({required BuildContext context, bool dismiss = false, WidgetBuilder? builder, Color color = Colors.black54, String? name}) → Future<T?>
弹出 dialog